

#include <opencv2/opencv.hpp>
#include "mex.h"
#include "opencv_matlab.hpp"

void 
mexFunction(int nlhs, mxArray *plhs[], 
            int nrhs, const mxArray *prhs[])
{
   
    //validate input
    if (nrhs == 0)
    {
        mexErrMsgTxt("An image is required!");
    }
    if (nlhs != 1)
    {
        mexErrMsgTxt("Only two output is provided.");
    }
    if(!mxIsDouble(prhs[0]) || ((mxGetNumberOfDimensions(prhs[0]) != 3) && (mxGetNumberOfDimensions(prhs[0]) != 2)))
    {
        mexErrMsgTxt("Type of the image has to be double.");
    }
    
    
    // determine input/output image properties
    const int *dimsA    = mxGetDimensions(prhs[0]);
    const int nDimsA    = mxGetNumberOfDimensions(prhs[0]);
    const int rowsA     = dimsA[0];
    const int colsA     = dimsA[1];
    const int channelsA = (nDimsA == 3 ? dimsA[2] : 1);
    
    double* pmag =  mxGetPr(prhs[1]);
    int mag = (int)pmag[0];

    cv::Mat imgA = cv::Mat::zeros(cv::Size(colsA, rowsA), CV_64F);
    om::copyMatrixToOpencv(mxGetPr(prhs[0]), imgA);
  
    cv::Mat pa = cv::Mat::zeros(imgA.size(), CV_64F);
    IplImage ipl_a = imgA, ipl_pa = pa;
    cvLogPolar(&ipl_a, &ipl_pa, cvPoint2D32f(imgA.cols >> 1, imgA.rows >> 1), mag);
   

    plhs[0] = mxCreateDoubleMatrix(colsA, rowsA,  mxREAL);
	double* out = mxGetPr(plhs[0]);
     om::copyMatrixToMatlab(pa, out);
}